@@ -22,12 +22,12 @@ require 'aprs4r/PluginConfiguration'
 
 class DigipeaterPluginConfiguration < PluginConfiguration
 
-  attr_reader :device, :call, :optimizePath, :cleanupPath, :enableRelay, :relayAliases, :enableWide
-  attr_writer :device, :call, :optimizePath, :cleanupPath, :enableRelay, :relayAliases, :enableWide
+  attr_reader :device, :call, :mode, :aliases, :hops
+  attr_writer :device, :call, :mode, :aliases, :hops
 
 
   def to_yaml_properties
-    %w{ super @device @call @optimizePath @cleanupPath @enableRelay @relayAliases @enableWide}
+    %w{ super @device @call @mode @aliases @hops}
   end
 
 end
