@@ -246,18 +246,18 @@ class WMRWeatherMessage
   end
 
 
-  def pressure
+  def pressure_base
     pressure = 0
 
     if has_baro? 
       case type
       when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR1
         if payload.length >= 6
-          pressure = payload[5] + 795
+          pressure = payload[5]
         end
       when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR2
         if payload.length >= 7
-          pressure = ((payload[6] & 0x01) << 8) + payload[5] + 600
+          pressure = ((payload[6] & 0x01) << 8) + payload[5]
         end
       end
     end
@@ -265,6 +265,48 @@ class WMRWeatherMessage
     return pressure
   end
 
+
+  def pressure_absolute
+    # absolute = base + fixed offset
+    pressure = pressure_base
+
+    if has_baro? 
+      case type
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR1
+        pressure += 795.0
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR2
+        pressure += 600.0
+      end
+    end
+
+    return pressure
+  end
+
+
+  def pressure_relative
+    # relative = base + sea level offset + correction (if neccessary)
+    pressure = pressure_base
+
+    if has_baro?
+      case type
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR1
+        if payload.length >= 9
+          offset = high_nibble( payload[8]) * 100.0 + low_nibble( payload[8]) * 10.0 + high_nibble( payload[7]) + low_nibble( payload[7]) / 10.0
+          offset += 1000.0 if offset < 400.0
+          pressure += offset
+        end
+      when @@WMR_MESSAGE_TYPE_THERMO_HYGRO_BARO_INDOOR2
+        if payload.length >= 10
+          offset = high_nibble( payload[9]) * 1000.0 + low_nibble( payload[9]) * 100.0 + high_nibble( payload[8]) * 10.0 + low_nibble( payload[8]) + high_nibble( payload[7]) / 10.0
+          pressure += offset
+        end
+      end
+    end
+    
+    return pressure
+  end
+
+
   def minute
     minute = 0
 
