@@ -20,6 +20,7 @@
 require 'Logger'
 
 require 'serialport'
+require 'thread'
 
 require 'aprs4r/APRSMessage'
 require 'aprs4r/WeatherPlugin'
@@ -153,8 +154,8 @@ class WMRWeatherPlugin < WeatherPlugin
       end
 
       if record.has_baro?
-        @@logger.info( "baro: pressure: #{record.pressure}")
-        @pressure = record.pressure
+        @@logger.info( "baro: pressure: #{record.pressure_relative}")
+        @pressure = record.pressure_relative
       end
     else 
       @@logger.warn( "empty record received")
@@ -174,6 +175,7 @@ class WMRWeatherPlugin < WeatherPlugin
     # read until HEADER
     value = @port.getc
     while value != WMRWeatherMessage.WMR_HEADER
+      print "value: #{value.chr.to_i}\n"
       value = @port.getc
     end
 
