@@ -23,6 +23,7 @@ require 'aprs4r/APRSMessage'
 require 'aprs4r/Plugin'
 require 'aprs4r/XMLDataPluginConfiguration'
 
+
 class XMLDataPlugin < Plugin
 
   @@logger = Logger.get_logger( "XMLDataPlugin")
@@ -40,6 +41,15 @@ class XMLDataPlugin < Plugin
     @latitude = configuration.latitude
     @longitude = configuration.longitude
 
+    # use default value if timeout is missed
+    @timeout = 1800
+    @timeout = configuration.timeout if configuration.timeout
+
+    # use default value if period is missed
+    @period = 15
+    @period = configuration.period if configuration.period
+
+
     @timestamps = Hash.new
     @messages = Hash.new
 
@@ -107,37 +117,37 @@ class XMLDataPlugin < Plugin
 
     if message.has_symbol? 
       @symbols[source] = message
-      @@logger.warn( "message: symbol: #{message.symbol_code} name: #{message.symbol_name}")
+      # @@logger.warn( "message: symbol: #{message.symbol_code} name: #{message.symbol_name}")
     end
 
     if message.has_position?
       @positions[source] = message
-      @@logger.warn( "message: lat: #{message.latitude} long: #{message.longitude}")
+      # @@logger.warn( "message: lat: #{message.latitude} long: #{message.longitude}")
     end
 
     if message.has_comment?
       @comments[source] = message
-      @@logger.warn( "message: comment: #{message.comment}")
+      # @@logger.warn( "message: comment: #{message.comment}")
     end
 
     if message.has_status?
       @states[source] = message
-      @@logger.warn( "message: status: #{message.status}")
+      # @@logger.warn( "message: status: #{message.status}")
     end
 
     if message.has_weather?
       @weathers[source] = message
-      @@logger.warn( "message: weather: wind: direction: #{message.weather_wind_direction} speed: #{message.weather_wind_speed} temperature: #{message.weather_temperature} humidity: #{message.weather_humidity} pressure: #{message.weather_pressure} rain: #{message.weather_rain}")
+      # @@logger.warn( "message: weather: wind: direction: #{message.weather_wind_direction} speed: #{message.weather_wind_speed} temperature: #{message.weather_temperature} humidity: #{message.weather_humidity} pressure: #{message.weather_pressure} rain: #{message.weather_rain}")
     end
 
     if message.has_course?
       @courses[source] = message
-      @@logger.warn( "message: course: direction: #{message.course_direction} speed: #{message.course_speed}")
+      # @@logger.warn( "message: course: direction: #{message.course_direction} speed: #{message.course_speed}")
     end
 
     if message.has_phg?
       @phgs[source] = message
-      @@logger.warn( "message: phg: power: #{message.phg_power} height: #{message.phg_height} gain: #{message.phg_gain} direction: #{message.phg_direction}")
+      # @@logger.warn( "message: phg: power: #{message.phg_power} height: #{message.phg_height} gain: #{message.phg_gain} direction: #{message.phg_direction}")
     end
 
     return
@@ -153,7 +163,7 @@ class XMLDataPlugin < Plugin
 
       # clean up station hash
       @timestamps.each{ |key, timestamp|
-        if now - timestamp > 1800
+        if now - timestamp > @timeout
           @timestamps.delete( key)
 
           @messages.delete( key)
@@ -170,9 +180,14 @@ class XMLDataPlugin < Plugin
 
       file = File.new( @file, "w")
 
+      # write xml header
+      file.puts( "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>")
+
+      # write stations element
       stations = sprintf( "<stations call=\"%s\" lat=\"%02.04f\" lng=\"%03.04f\">", @call, @latitude, @longitude)
       file.puts( stations)
 
+      # write station element for each station
       @messages.each{ |key, message|
 
         if message
@@ -257,7 +272,7 @@ class XMLDataPlugin < Plugin
 
       file.close
 
-      sleep 10
+      sleep @period
 
     end
 
